"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const $ = require("jquery");
const apputils_1 = require("@jupyterlab/apputils");
const outputarea_1 = require("@jupyterlab/outputarea");
const output_1 = require("@jupyter-widgets/output");
const algorithm_1 = require("@phosphor/algorithm");
const messaging_1 = require("@phosphor/messaging");
const coreutils_1 = require("@phosphor/coreutils");
const widgets_1 = require("@phosphor/widgets");
require("../css/SidePanel.css");
class SidePanel extends output_1.OutputView {
    constructor(options) {
        // console.log('SidePanel2', options);
        super(options);
        this.app = options.app;
    }
    _createElement(tagName) {
        // console.log('create element', tagName);
        this.pWidget = new SidePanelOutputArea({ view: this });
        return this.pWidget.node;
    }
    _setElement(el) {
        // console.log('set element', el);
        if (this.el || el !== this.pWidget.node) {
            throw new Error('Cannot reset the DOM element.');
        }
        this.el = this.pWidget.node;
        this.$el = $(this.pWidget.node);
    }
    render() {
        super.render();
        this.outputArea = new outputarea_1.SimplifiedOutputArea({
            rendermime: this.model.widget_manager.rendermime,
            contentFactory: outputarea_1.SimplifiedOutputArea.defaultContentFactory,
            model: this.model.outputs
        });
        this.outputArea.addClass('sidepanel');
        this.outputArea.addClass('jp-LinkedOutputView');
        this.update();
        let shell = this.app.shell;
        let w = new apputils_1.MainAreaWidget({ content: this.outputArea });
        w.id = `SidePanel-${coreutils_1.UUID.uuid4()}`;
        w.title.label = this.model.get('title') || '';
        w.title.closable = true;
        this.outputArea.model.changed.connect(this.refresh, this);
        let ref_id = null;
        let label = this.model.get('ref');
        if (label) {
            let ref = algorithm_1.find(shell.widgets('main'), w => w.title.label == label);
            if (ref)
                ref_id = ref.id;
        }
        shell.add(w, 'main', { mode: this.model.get('side'), ref: ref_id });
    }
    refresh(model, args) {
        // console.log('sidepanel.referesh', model, args);
        messaging_1.MessageLoop.postMessage(this.outputArea, new messaging_1.Message('resize'));
    }
    remove() {
        this.outputArea.dispose();
        return super.remove();
    }
}
exports.SidePanel = SidePanel;
//
// SidePanelOutputArea
//
class SidePanelOutputArea extends widgets_1.Panel {
    constructor(options) {
        let view = options.view;
        delete options.view;
        super(options);
        this._view = view;
    }
    processMessage(msg) {
        super.processMessage(msg);
        this._view.processPhosphorMessage(msg);
    }
    dispose() {
        if (this.isDisposed) {
            return;
        }
        super.dispose();
        if (this._view) {
            this._view.remove();
        }
        this._view = null;
    }
}
